import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeDropdownList";
var CLASS_HIDDEN = "is-hidden";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};

var MoleculeDropdownList = function MoleculeDropdownList(_ref) {
  var _cx;

  var children = _ref.children,
      value = _ref.value,
      size = _ref.size,
      visible = _ref.visible,
      onSelect = _ref.onSelect,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "value", "size", "visible", "onSelect"]);

  var refDropdownList = useRef();
  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    var valueChild = child.props.value;
    var selected = Array.isArray(value) ? value.includes(valueChild) : value === valueChild;
    return React.cloneElement(child, _objectSpread({}, props, {
      index: index,
      onSelect: onSelect,
      selected: selected
    }));
  });
  var classNames = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_HIDDEN] = !visible, _cx));

  var getFocusedOptionIndex = function getFocusedOptionIndex(options) {
    var currentElementFocused = document.activeElement;
    return Array.from(options).reduce(function (focusedOptionIndex, option, index) {
      if (option === currentElementFocused) focusedOptionIndex = index;
      return focusedOptionIndex;
    }, 0);
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var key = ev.key;
    var options = refDropdownList.current.children;
    var numOptions = options.length;

    if (key === 'ArrowDown' || key === 'ArrowUp') {
      var index = getFocusedOptionIndex(options);

      if (index >= 0 || index <= numOptions) {
        if (key === 'ArrowDown' && index < numOptions - 1) options[index + 1].focus();
        if (key === 'ArrowUp' && index > 0) options[index - 1].focus();
      }

      ev.preventDefault();
      ev.stopPropagation();
    }
  };

  return React.createElement("ul", {
    ref: refDropdownList,
    tabIndex: "0",
    onKeyDown: handleKeyDown,
    className: classNames
  }, extendedChildren);
};

MoleculeDropdownList.displayName = 'MoleculeDropdownList';
MoleculeDropdownList.defaultProps = {
  size: SIZES.SMALL,
  onSelect: function onSelect() {}
};
export default MoleculeDropdownList;
export { SIZES as moleculeDropdownListSizes };